# Physics

::: inspeqtor.physics

::: inspeqtor.physics.solver

::: inspeqtor.physics.auto_rotating_frame_hamiltonian

::: inspeqtor.physics.explicit_auto_rotating_frame_hamiltonian

::: inspeqtor.physics.a

::: inspeqtor.physics.a_dag

::: inspeqtor.physics.N

::: inspeqtor.physics.tensor

::: inspeqtor.physics.make_signal_fn

::: inspeqtor.physics.gate_fidelity

::: inspeqtor.physics.process_fidelity

::: inspeqtor.physics.avg_gate_fidelity_from_superop

::: inspeqtor.physics.to_superop

::: inspeqtor.physics.state_tomography

::: inspeqtor.physics.check_valid_density_matrix

::: inspeqtor.physics.check_hermitian

::: inspeqtor.physics.direct_AGF_estimation_fn

::: inspeqtor.physics.calculate_exp

::: inspeqtor.physics.make_trotterization_solver

::: inspeqtor.physics.lindblad_solver

## Library

::: inspeqtor.physics.library

::: inspeqtor.physics.library.transmon_hamiltonian

::: inspeqtor.physics.library.rotating_transmon_hamiltonian

::: inspeqtor.physics.library.detune_x_hamiltonian

::: inspeqtor.physics.library.SimulationStrategy

::: inspeqtor.physics.library.WhiteboxStrategy

::: inspeqtor.physics.library.HamiltonianEnum

::: inspeqtor.physics.library.HamiltonianSpec
